Block class

Represents a group of adjacent Lines with the same block style.

Block elements are:

  • Blockquote
  • Header
  • Indent
  • List
  • Text Alignment
  • Text Direction
  • Code Block
Inheritance

Constructors

Block()

Properties

childCount → int
Returns total number of child nodes in this container.
no setterinherited
children → LinkedList<Node>
List of children.
no setterinherited
defaultChild → Line
Returns an instance of default child for this container node.
no setteroverride
documentOffset → int
Offset in characters of this node in the document.
no setterinherited
first → Node
Returns the first child Node.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Returns true if this container has no child nodes.
no setterinherited
isFirst → bool
Returns true if this node is the first node in the parent list.
no setterinherited
isLast → bool
Returns true if this node is the last node in the parent list.
no setterinherited
isNotEmpty → bool
Returns true if this container has at least 1 child.
no setterinherited
last → Node
Returns the last child Node.
no setterinherited
length → int
Content length of this node's children.
no setterinherited
list → LinkedList<Node>?
The linked list containing this element.
no setterinherited
next → Node?
The successor of this element in its linked list.
no setterinherited
offset → int
Offset in characters of this node relative to parent node.
no setterinherited
parent ↔ Container<Node?>?
Current parent of this node. May be null if this node is not mounted.
getter/setter pairinherited
previous → Node?
The predecessor of this element in its linked list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style
no setterinherited

Methods

add(Line? node) → void
Adds node to the end of this container children list.
inherited
addFirst(Line? node) → void
Adds node to the beginning of this container children list.
inherited
adjust() → void
override
applyAttribute(Attribute attribute) → void
inherited
applyStyle(Style value) → void
inherited
clearStyle() → void
inherited
clone() → Node
inherited
containsOffset(int offset) → bool
Returns true if this node contains character at specified offset in the document.
inherited
delete(int index, int? length) → void
inherited
insert(int index, Object data, Style? style) → void
inherited
insertAfter(Node entry) → void
Insert an element after this element in this element's linked list.
inherited
insertBefore(Node entry) → void
Insert an element before this element in this element's linked list.
inherited
moveChildToNewParent(Container<Node?>? newParent) → void
Moves children of this node to newParent.
inherited
newInstance() → Node
Creates new unmounted Block.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryChild(int offset, bool inclusive) → ChildQuery
Queries the child Node at offset in this container.
inherited
remove(Line? node) → void
Removes node from this container.
inherited
retain(int index, int? length, Style? attributes) → void
inherited
toDelta() → Delta
override
toPlainText() → String
inherited
toString() → String
A string representation of this object.
override
Unlink the element from its linked list.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited