PreserveLineStyleOnSplitRule class

Inheritance

Constructors

PreserveLineStyleOnSplitRule()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RuleType
no setterinherited

Methods

apply(Delta document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
inherited
applyRule(Delta document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateArgs(int? len, Object? data, Attribute? attribute) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited