RawEditorState class

Inheritance
Mixed-in types

Constructors

RawEditorState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
copyEnabled → bool
Whether copy is enabled.
no setterinherited
currentAutofillScope → AutofillScope?
The AutofillScope this TextInputClient belongs to, if any.
no setterinherited
currentTextEditingValue → TextEditingValue?
The current state of the TextEditingValue held by this client.
no setterinherited
cutEnabled → bool
Whether cut is enabled.
no setterinherited
hasConnection → bool
Returns true if there is open input connection.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
liveTextInputEnabled → bool
Whether Live Text input is enabled.
no setterinherited
lookUpEnabled → bool
Whether look up is enabled.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
pasteEnabled → bool
Whether paste is enabled.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController
no setteroverride
searchWebEnabled → bool
Whether search web is enabled.
no setterinherited
selectAllEnabled → bool
Whether select all is enabled.
no setterinherited
shareEnabled → bool
Whether share is enabled.
no setterinherited
shouldCreateInputConnection → bool
Whether to create an input connection with the platform for text editing or not.
no setterinherited
textEditingValue ↔ TextEditingValue
Gets the current text input.
getter/setter pairinherited
wantKeepAlive → bool
Whether the current instance should be kept alive.
no setteroverride
widget → RawEditor
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
bringIntoView(TextPosition position) → void
Brings the provided TextPosition into the visible area of the text input.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
closeConnectionIfNeeded() → void
Closes input connection if it's currently open. Otherwise does nothing.
inherited
connectionClosed() → void
Platform notified framework of closed connection.
inherited
copySelection(SelectionChangedCause cause) → void
Copy current selection to Clipboard.
override
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
cutSelection(SelectionChangedCause cause) → void
Cut current selection to Clipboard.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didChangeInputControl(TextInputControl? oldControl, TextInputControl? newControl) → void
The framework calls this method to notify that the text input control has been changed.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() → Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) → Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) → Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() → Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
didUpdateWidget(covariant RawEditor oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
getRenderEditor() → RenderEditor?
override
getSelectionOverlay() → EditorTextSelectionOverlay?
override
getTextEditingValue() → TextEditingValue
override
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleCursorMovement(LogicalKeyboardKey key, bool wordModifier, bool lineModifier, bool shift) → void
inherited
handleDelete(bool forward) → void
inherited
handleShortcut(InputShortcut? shortcut) → Future<void>
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) → bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
hideToolbar([bool hideHandles = true]) → void
inherited
initState() → void
Called when this object is inserted into the tree.
override
insertContent(KeyboardInsertedContent content) → void
Notify client about new content insertion from Android keyboard.
inherited
insertTextPlaceholder(Size size) → void
Requests that the client add a text placeholder to reserve visual space in the text.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFocusReceived() → bool
Notifies the client that the platform moved focus back to this input.
inherited
openConnectionIfNeeded() → void
inherited
openOrCloseConnection() → void
Opens or closes input connection based on the current state of focusNode and value.
inherited
pasteText(SelectionChangedCause cause) → Future<void>
Paste text from Clipboard.
override
performAction(TextInputAction action) → void
Requests that this client perform the given action.
inherited
performPrivateCommand(String action, Map<String, dynamic> data) → void
Request from the input method that this client perform the given private command.
inherited
performSelector(String selectorName) → void
Performs the specified MacOS-specific selector from the NSStandardKeyBindingResponding protocol or user-specified selector from DefaultKeyBinding.Dict.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeTextPlaceholder() → void
Requests that the client remove the text placeholder.
override
requestKeyboard() → void
override
selectAll(SelectionChangedCause cause) → void
Set the current selection to contain the entire text value.
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setTextEditingValue(TextEditingValue value) → void
override
showAutocorrectionPromptRect(int start, int end) → void
Requests that this client display a prompt rectangle for the given text range, to indicate the range of text that will be changed by a pending autocorrection.
inherited
showToolbar() → bool
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateEditingValue(TextEditingValue value) → void
Requests that this client update its editing state to the given value.
inherited
updateFloatingCursor(RawFloatingCursorPoint point) → void
Updates the floating cursor position and state.
inherited
updateKeepAlive() → void
Ensures that any AutomaticKeepAlive ancestors are in a good state, by firing a KeepAliveNotification or triggering the KeepAliveHandle as appropriate.
inherited
updateRemoteValueIfNeeded() → void
Updates remote value based on current state of document and selection.
inherited
userUpdateTextEditingValue(TextEditingValue value, SelectionChangedCause cause) → void
Indicates that the user has requested the delegate to replace its current text editing state with value.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited